@@ -52,7 +52,7 @@ class CORE_EXPORT QgsProcessingUtils
      * Returns a list of raster layers from a \a project which are compatible with the processing
      * framework.
      *
-     * If the \a sort argument is true then the layers will be sorted by their QgsMapLayer::name()
+     * If the \a sort argument is TRUE then the layers will be sorted by their QgsMapLayer::name()
      * value.
      * \see compatibleVectorLayers()
      * \see compatibleMeshLayers()
@@ -69,7 +69,7 @@ class CORE_EXPORT QgsProcessingUtils
      * layers with the specified source type included in the list will be returned. Leaving the \a sourceTypes
      * list empty will cause all vector layers, regardless of their geometry type, to be returned.
      *
-     * If the \a sort argument is true then the layers will be sorted by their QgsMapLayer::name()
+     * If the \a sort argument is TRUE then the layers will be sorted by their QgsMapLayer::name()
      * value.
      * \see compatibleRasterLayers()
      * \see compatibleMeshLayers()
@@ -83,7 +83,7 @@ class CORE_EXPORT QgsProcessingUtils
      * Returns a list of mesh layers from a \a project which are compatible with the processing
      * framework.
      *
-     * If the \a sort argument is true then the layers will be sorted by their QgsMapLayer::name()
+     * If the \a sort argument is TRUE then the layers will be sorted by their QgsMapLayer::name()
      * value.
      *
      * \see compatibleRasterLayers()
@@ -98,7 +98,7 @@ class CORE_EXPORT QgsProcessingUtils
      * Returns a list of map layers from a \a project which are compatible with the processing
      * framework.
      *
-     * If the \a sort argument is true then the layers will be sorted by their QgsMapLayer::name()
+     * If the \a sort argument is TRUE then the layers will be sorted by their QgsMapLayer::name()
      * value.
      * \see compatibleRasterLayers()
      * \see compatibleVectorLayers()
@@ -109,7 +109,7 @@ class CORE_EXPORT QgsProcessingUtils
      * Layer type hints.
      * \since QGIS 3.4
      */
-    enum LayerHint
+    enum class LayerHint SIP_MONKEYPATCH_SCOPEENUM : int
     {
       UnknownType, //!< Unknown layer type
       Vector, //!< Vector layer type
@@ -123,13 +123,13 @@ class CORE_EXPORT QgsProcessingUtils
      * The method will attempt to
      * load a layer matching the passed \a string. E.g. if the string matches a layer ID or name
      * within the context's project or temporary layer store then this layer will be returned.
-     * If the string is a file path and \a allowLoadingNewLayers is true, then the layer at this
+     * If the string is a file path and \a allowLoadingNewLayers is TRUE, then the layer at this
      * file path will be loaded and added to the context's temporary layer store.
      * Ownership of the layer remains with the \a context or the context's current project.
      *
      * The \a typeHint can be used to dictate the type of map layer expected.
      */
-    static QgsMapLayer *mapLayerFromString( const QString &string, QgsProcessingContext &context, bool allowLoadingNewLayers = true, LayerHint typeHint = UnknownType );
+    static QgsMapLayer *mapLayerFromString( const QString &string, QgsProcessingContext &context, bool allowLoadingNewLayers = true, QgsProcessingUtils::LayerHint typeHint = QgsProcessingUtils::LayerHint::UnknownType );
 
     /**
      * Converts a variant \a value to a new feature source.
@@ -213,11 +213,21 @@ class CORE_EXPORT QgsProcessingUtils
      */
     static void createFeatureSinkPython( QgsFeatureSink **sink SIP_OUT SIP_TRANSFERBACK, QString &destination SIP_INOUT, QgsProcessingContext &context, const QgsFields &fields, QgsWkbTypes::Type geometryType, const QgsCoordinateReferenceSystem &crs, const QVariantMap &createOptions = QVariantMap() ) SIP_THROW( QgsProcessingException ) SIP_PYNAME( createFeatureSink );
 
+
+    /**
+     * Combines the extent of several map \a layers. If specified, the target \a crs
+     * will be used to transform the layer's extent to the desired output reference system
+     * using the specified \a context.
+     * \since QGIS 3.8
+     */
+    static QgsRectangle combineLayerExtents( const QList<QgsMapLayer *> &layers, const QgsCoordinateReferenceSystem &crs, QgsProcessingContext &context );
+
     /**
      * Combines the extent of several map \a layers. If specified, the target \a crs
      * will be used to transform the layer's extent to the desired output reference system.
+     * \deprecated Use version with QgsProcessingContext argument instead
      */
-    static QgsRectangle combineLayerExtents( const QList<QgsMapLayer *> &layers, const QgsCoordinateReferenceSystem &crs = QgsCoordinateReferenceSystem() );
+    Q_DECL_DEPRECATED static QgsRectangle combineLayerExtents( const QList<QgsMapLayer *> &layers, const QgsCoordinateReferenceSystem &crs = QgsCoordinateReferenceSystem() ) SIP_DEPRECATED;
 
     /**
      * Converts an \a input parameter value for use in source iterating mode, where one individual sink
@@ -248,7 +258,7 @@ class CORE_EXPORT QgsProcessingUtils
     static QString formatHelpMapAsHtml( const QVariantMap &map, const QgsProcessingAlgorithm *algorithm );
 
     /**
-     * Converts a source vector \a layer to a file path to a vector layer of compatible format.
+     * Converts a source vector \a layer to a file path of a vector layer of compatible format.
      *
      * If the specified \a layer is not of the format listed in the
      * \a compatibleFormats argument, then the layer will first be exported to a compatible format
@@ -258,6 +268,11 @@ class CORE_EXPORT QgsProcessingUtils
      *
      * The \a preferredFormat argument is used to specify to desired file extension to use when a temporary
      * layer export is required. This defaults to shapefiles.
+     *
+     * When an algorithm is capable of handling multi-layer input files (such as Geopackage), it is preferable
+     * to use convertToCompatibleFormatAndLayerName() which may avoid conversion in more situations.
+     *
+     * \see convertToCompatibleFormatAndLayerName()
      */
     static QString convertToCompatibleFormat( const QgsVectorLayer *layer,
         bool selectedFeaturesOnly,
@@ -267,6 +282,45 @@ class CORE_EXPORT QgsProcessingUtils
         QgsProcessingContext &context,
         QgsProcessingFeedback *feedback );
 
+    /**
+     * Converts a source vector \a layer to a file path and layer name of a vector layer of compatible format.
+     *
+     * If the specified \a layer is not of the format listed in the
+     * \a compatibleFormats argument, then the layer will first be exported to a compatible format
+     * in a temporary location using \a baseName. The function will then return the path to that temporary file.
+     *
+     * \a compatibleFormats should consist entirely of lowercase file extensions, e.g. 'shp'.
+     *
+     * The \a preferredFormat argument is used to specify to desired file extension to use when a temporary
+     * layer export is required. This defaults to shapefiles.
+     *
+     * This method should be preferred over convertToCompatibleFormat() when an algorithm is able
+     * to correctly handle files with multiple layers. Unlike convertToCompatibleFormat(), it will not force
+     * a conversion in this case and will return the target layer name in the \a layerName argument.
+     *
+     * \param layer source layer to convert (if required)
+     * \param selectedFeaturesOnly TRUE if only selected features from the layer should be used
+     * \param baseName base file name for converted layer, if required
+     * \param compatibleFormats a list of lowercase file extensions compatible with the algorithm
+     * \param preferredFormat preferred format extension to use if conversion if required
+     * \param context processing context
+     * \param feedback feedback object
+     * \param layerName will be set to the target layer name for multi-layer sources (e.g. Geopackage)
+     *
+     * \returns path to source layer, or nearly converted compatible layer
+     *
+     * \see convertToCompatibleFormat()
+     * \since QGIS 3.10
+     */
+    static QString convertToCompatibleFormatAndLayerName( const QgsVectorLayer *layer,
+        bool selectedFeaturesOnly,
+        const QString &baseName,
+        const QStringList &compatibleFormats,
+        const QString &preferredFormat,
+        QgsProcessingContext &context,
+        QgsProcessingFeedback *feedback,
+        QString &layerName SIP_OUT );
+
     /**
      * Combines two field lists, avoiding duplicate field names (in a case-insensitive manner).
      *
@@ -277,7 +331,7 @@ class CORE_EXPORT QgsProcessingUtils
      * length of field names, so be aware that the results of calling this method may
      * be truncated when saving to these formats.
      */
-    static QgsFields combineFields( const QgsFields &fieldsA, const QgsFields &fieldsB );
+    static QgsFields combineFields( const QgsFields &fieldsA, const QgsFields &fieldsB, const QString &fieldsBPrefix = QString() );
 
     /**
      * Returns a list of field indices parsed from the given list of field names. Unknown field names are ignored.
@@ -292,6 +346,30 @@ class CORE_EXPORT QgsProcessingUtils
      */
     static QgsFields indicesToFields( const QList<int> &indices, const QgsFields &fields );
 
+    /**
+     * Returns the default vector extension to use, in the absence of all other constraints (e.g.
+     * provider based support for extensions).
+     *
+     * This method returns the user-set default extension from the processing settings, or
+     * a fallback value of "gpkg".
+     *
+     * \see defaultRasterExtension()
+     * \since QGIS 3.10
+     */
+    static QString defaultVectorExtension();
+
+    /**
+     * Returns the default raster extension to use, in the absence of all other constraints (e.g.
+     * provider based support for extensions).
+     *
+     * This method returns the user-set default extension from the processing settings, or
+     * a fallback value of "tif".
+     *
+     * \see defaultVectorExtension()
+     * \since QGIS 3.10
+     */
+    static QString defaultRasterExtension();
+
   private:
     static bool canUseLayer( const QgsRasterLayer *layer );
     static bool canUseLayer( const QgsMeshLayer *layer );
@@ -308,15 +386,29 @@ class CORE_EXPORT QgsProcessingUtils
      * returned.
      * \see mapLayerFromString()
      */
-    static QgsMapLayer *mapLayerFromStore( const QString &string, QgsMapLayerStore *store, LayerHint typeHint = UnknownType );
+    static QgsMapLayer *mapLayerFromStore( const QString &string, QgsMapLayerStore *store, QgsProcessingUtils::LayerHint typeHint = QgsProcessingUtils::LayerHint::UnknownType );
+
+    /**
+     * Interprets a string as a map layer. The method will attempt to
+     * load a layer matching the passed \a string using the given coordinate
+     * \a transformContext.
+     * E.g. if the string is a file path,
+     * then the layer at this file path will be loaded.
+     * The caller takes responsibility for deleting the returned map layer.
+     *
+     * \since QGIS 3.8
+     */
+    static QgsMapLayer *loadMapLayerFromString( const QString &string, const QgsCoordinateTransformContext &transformContext, LayerHint typeHint = LayerHint::UnknownType );
 
     /**
      * Interprets a string as a map layer. The method will attempt to
      * load a layer matching the passed \a string. E.g. if the string is a file path,
      * then the layer at this file path will be loaded.
      * The caller takes responsibility for deleting the returned map layer.
+     *
+     * \deprecated use mapLayerFromString() that takes QgsCoordinateTransformContext as an argument instead
      */
-    static QgsMapLayer *loadMapLayerFromString( const QString &string, LayerHint typeHint = UnknownType );
+    Q_DECL_DEPRECATED static QgsMapLayer *loadMapLayerFromString( const QString &string, LayerHint typeHint = LayerHint::UnknownType ) SIP_DEPRECATED ;
 
     static void parseDestinationString( QString &destination, QString &providerKey, QString &uri, QString &layerName, QString &format, QMap<QString, QVariant> &options, bool &useWriter, QString &extension );
 
@@ -346,9 +438,9 @@ class CORE_EXPORT QgsProcessingFeatureSource : public QgsFeatureSource
     /**
      * Constructor for QgsProcessingFeatureSource, accepting an original feature source \a originalSource
      * and processing \a context.
-     * Ownership of \a originalSource is dictated by \a ownsOriginalSource. If \a ownsOriginalSource is false,
+     * Ownership of \a originalSource is dictated by \a ownsOriginalSource. If \a ownsOriginalSource is FALSE,
      * ownership is not transferred, and callers must ensure that \a originalSource exists for the lifetime of this object.
-     * If \a ownsOriginalSource is true, then this object will take ownership of \a originalSource.
+     * If \a ownsOriginalSource is TRUE, then this object will take ownership of \a originalSource.
      */
     QgsProcessingFeatureSource( QgsFeatureSource *originalSource, const QgsProcessingContext &context, bool ownsOriginalSource = false );
 
@@ -413,9 +505,9 @@ class CORE_EXPORT QgsProcessingFeatureSink : public QgsProxyFeatureSink
      *
      * The \a sinkName is used to identify the destination sink when reporting errors.
      *
-     * Ownership of \a originalSink is dictated by \a ownsOriginalSource. If \a ownsOriginalSink is false,
+     * Ownership of \a originalSink is dictated by \a ownsOriginalSource. If \a ownsOriginalSink is FALSE,
      * ownership is not transferred, and callers must ensure that \a originalSink exists for the lifetime of this object.
-     * If \a ownsOriginalSink is true, then this object will take ownership of \a originalSink.
+     * If \a ownsOriginalSink is TRUE, then this object will take ownership of \a originalSink.
      */
     QgsProcessingFeatureSink( QgsFeatureSink *originalSink, const QString &sinkName, QgsProcessingContext &context, bool ownsOriginalSink = false );
     ~QgsProcessingFeatureSink() override;
